/*****************************************************************************
 *
 * Copyright (C) 2023 Daniel Ramirez <dr@igh.de>
 *               2023 Florian Pose <fp@igh.de>
 *
 * This file is part of the QtPdWidgets library.
 *
 * The QtPdWidgets library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * The QtPdWidgets library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with the QtPdWidgets Library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 ****************************************************************************/

#include "ParameterFileSystemModel.h"

#include <QFileIconProvider>

using Pd::ParameterFileSystemModel;

/*****************************************************************************
 * public
 ****************************************************************************/

ParameterFileSystemModel::ParameterFileSystemModel(QObject *parent) :
    files(QFileInfoList())
{
    Q_UNUSED(parent);
}

/****************************************************************************/

ParameterFileSystemModel::~ParameterFileSystemModel()
{}

/****************************************************************************/

int ParameterFileSystemModel::rowCount(const QModelIndex &parent) const
{
    int ret = 0;

    if (parent.isValid()) {
        qWarning() << __func__ << parent << "inval";
    }
    else {
        ret = files.size();
    }

#ifdef DEBUG_FILESYSTEM
    qDebug() << __func__ << parent << ret;
#endif

    return ret;
}

/****************************************************************************/

QVariant ParameterFileSystemModel::data(const QModelIndex &index, int role) const
{
    QVariant ret;

    if (index.isValid()) {

        QFileInfo info = files.at(index.row());

        switch (role) {
            case Qt::DisplayRole:
                {
                    ret = info.fileName();
                }
                break;
            case Qt::BackgroundRole:
                {
                    ret = QVariant();
                }
                break;
            case Qt::DecorationRole:
                {
                    QFileIconProvider iconP;
                    ret = iconP.icon(info);
                }
                break;
            default:
                break;
        }
    }

#ifdef DEBUG_FILESYSTEM
    if (role <= 1) {
        qDebug() << __func__ << index << role << ret;
    }
#endif

    return ret;
}

/***************************************************************************/

void ParameterFileSystemModel::setPath(const QString path)
{
    files = (QDir(path).entryInfoList(QDir::Files));
}
